@@ -1,7 +1,7 @@
 <?php
 
-# FitGallery 0.85
-# (C) Omar Lpez 'pollo' (pollo.es.pollo@gmail.com), Enrique D. Bosch 'presi' (presidev@confluencia.net)
+# FitGallery 0.90
+# (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
 # show exif thumbnail
@@ -11,7 +11,7 @@
 
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
+#    the Free Software Foundation; either version 3 of the License, or
 #    (at your option) any later version.
 #
 #    This program is distributed in the hope that it will be useful,
@@ -20,8 +20,7 @@
 #    GNU General Public License for more details.
 #
 #    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 #    http://www.gnu.org/licenses/gpl.html
 
@@ -29,18 +28,23 @@ include 'common_sec.php';
 
 function exif_thumb($valor,$galeria)
 {
-    include 'config/config-thumb.php';
+    include 'config/config-common.php';
 
     $dg="$dirgal/$galeria";
     $fichero="$dg/imgs/$valor";
 
+    if (!is_dir($dg)) exit_error('Gallery not found.');
+    if (!is_file($fichero)) exit_error('Image not found.');
+
     $image = exif_thumbnail($fichero, $width, $height, $type);
     header('Content-type: ' .image_type_to_mime_type($type));
     echo $image;
 }
 
-$img=check_input($_GET['img'],$VALID_CHARS);
-$galeria=check_input($_GET['galeria'],$VALID_CHARS);
+$img=check_input($_GET['img'],VALID_CHARS);
+$galeria=check_input($_GET['galeria'],VALID_CHARS);
+
+if ($img=='' || $galeria=='') exit_error('Missing argument.');
 
 exif_thumb($img,$galeria);
 
