@@ -1,8 +1,10 @@
 <?php
 
-# Default css sheet FitGallery 0.85 by Pollo (pollo.es.pollo@gmail.com) and Presi (presidev@confluencia.net)
+# Default css sheet for FitGallery 0.90
 # random multicolor background, red border boxes
+# under public domain
 
+header('Content-type: text/css');
 echo '
 div.figure
 {
@@ -16,17 +18,18 @@ p.caption
 {
   font-size: smaller;
   text-indent: 0;
+  white-space: nowrap;
 }
 p.clear,p.nav,form.tpp
 { 
   clear: left;
   text-align: center;
 }
-p.normal,h3.normal,h4.normal
+p.normal,p.clear,h2.normal,h3.normal,h4.normal
 { 
   text-align: center;
 }
-img.thumbnail,img.w3c
+img.thumbnail,img.exif_thumb,img.w3c
 {
   border-style: none;
 }
@@ -50,6 +53,21 @@ a.texto:hover
   color: #0000ff;
   background: #ffffcc;
 }
+table.table_exif
+{
+  margin: auto;
+  text-align: center;
+}
+tr.table_header
+{
+  font-size: large;
+  text-align: center;
+}
+td.table_item
+{
+  border: thin red solid;
+  text-align: center;
+}
 body
 {
 ';
